@@ -5,7 +5,8 @@
 #' @param x  Result of a nlme fit, with named components `tempt, beta, logbeta,
 #' kappa, logkappa` depending on model. Function used `logbeta` when it is present,
 #' in `x`, otherwise beta, and similar for logkappa/kappa.
-#' @return Half-emptying time. Name of evaluated function is returned as attribute \code{fun}. Negative of slope is returned as attribute \code{slope}.
+#' @return Half-emptying time. Name of evaluated function is returned as
+#' attribute \code{fun}. Negative of slope is returned as attribute \code{slope}.
 #' @importFrom stats setNames
 #' @export
 t50 = function(x) {
@@ -13,7 +14,7 @@ t50 = function(x) {
 }
 
 #' @export
-t50.default = function(x){
+t50.default = function(x) {
   tempt = ifelse("logtempt" %in% names(x), exp(x["logtempt"]), x["tempt"])
   # Search interval is 5*tempt
   interval = c(.0001, 5*tempt)
@@ -25,10 +26,10 @@ t50.default = function(x){
       powexp_log(t, 1, x["logtempt"], x["logbeta"]) - 0.5,
       interval = interval)$root
     slope = powexp_slope(ret, v0, exp(x["logtempt"]), exp(x["logbeta"]))
-  } else if ( "beta" %in% names(x)) {
+  } else if ("beta" %in% names(x)) {
       ssfun = powexp
       ret = uniroot(function(t)
-        powexp(t, 1, x["tempt"], x["beta"] ) - 0.5,
+        powexp(t, 1, x["tempt"], x["beta"]) - 0.5,
         interval = interval)$root
         slope = powexp_slope(ret, v0, x["tempt"], x["beta"])
     } else
@@ -50,23 +51,22 @@ t50.default = function(x){
         }
   attr(ret, "auc") = as.numeric(auc)
   attr(ret, "slope") = -as.numeric(slope)
-  attr(ret, "fun" ) = ssfun
+  attr(ret, "fun") = ssfun
   ret
 }
 
 #' @export
-t50.data.frame = function(x){
-  assert_that(all(c("record","tempt","v0") %in% names(x)))
+t50.data.frame = function(x) {
+  assert_that(all(c("record", "tempt", "v0") %in% names(x)))
   x$t50 = 0
   x$slope_t50 = 0
   x$auc = NA_real_
-  for (i in 1:nrow(x)) {
+  for (i in seq_len(nrow(x))) {
     # Very ugly construct to restore old data frame drop behavior
-    tt =  t50(setNames(unlist(x[1,-1]), names(x[-1])))
-    x[i,"t50"] = as.numeric(tt)
-    x[i,"slope_t50"] = attr(tt,"slope")
-    x[i,"auc"] = attr(tt,"auc")
+    tt =  t50(setNames(unlist(x[1, -1]), names(x[-1])))
+    x[i, "t50"] = as.numeric(tt)
+    x[i, "slope_t50"] = attr(tt, "slope")
+    x[i, "auc"] = attr(tt, "auc")
   }
   x
 }
-
